==> rD3plot_1.1.37.zip: rD3plot/www/es.js <==
// texts to translate
var texts = {
    graph : "Gráfico",
    nodes : "Nodos",
    general: "General",
    links: "Enlaces",
    apply: "Aplicar",
    filter: "Filtrar",
    isolate: "Aislar",
    select: "Seleccionar",
    clear: "Limpiar",
    add: "Añadir",
    nodesattributes: "Atributos de nodos",
    linksattributes: "Atributos de enlaces",
    elementsattributes: "Atributos de elementos",
    nonodesselected: "Seleciona un nodo en el gráfico para ver sus atributos.",
    nolinksselected: "Seleciona un enlace en el gráfico para ver sus atributos.",
    noitemsselected: "Selecciona nodos o enlaces.",
    noelementsselected: "Selecciona elementos en el gráfico para ver sus atributos.",
    repulsion: "Repulsión",
    distance: "Distancia",
    loading: "Cargando...",
    pdfexport: "Exportación PDF",
    svgexport: "Exportación SVG",
    pngexport: "Exportación PNG",
    showHelp: "Mostrar ayuda",
    showhidelegend: "Leyenda",
    showhideaxes: "Ejes",
    showhidesidebar: "Mostrar/ocultar control lateral",
    showhidebuttons: "Mostrar/ocultar botones",
    showhidetables: "Mostrar/ocultar tablas",
    stopresume: "Dinámico",
    heatmap: "Heatmap",
    resetfilter: "Quitar filtros",
    selectall: "Seleccionar todos",
    selectallnone: "Seleccionar todos / ninguno",
    selectneighbors: "Añadir vecinos",
    expand: "Expandir",
    collapse: "Contraer",
    Reverse: "Invertir",
    tableselection: "Marcados en la tabla",
    reset: "Reiniciar",
    directional: "Flechas",
    degree: "grado",
    none: "Nada",
    default: "Por defecto",
    downloadtable: "Descargar tabla",
    total: "Total",
    concoincidences: "Coincidencias condicionales",
    coincidences: "Coincidencias",
    ofsomeone: "de",
    withsomeone: "con",
    incidences: "Incidencias",
    expected: "Esperadas",
    expectedconfidence: "+/- Confianza esperada",
    confidenceinterval: "+/- Intervalo de confianza",
    subjectselect: "Evento",
    Label: "Etiqueta",
    LabelSize: "Tam.Eti.",
    Group: "Grupo",
    Border: "Borde",
    Order: "Orden",
    Size: "Tamaño",
    Color: "Color",
    Shape: "Forma",
    Legend: "Leyenda",
    Image: "Imagen",
    Width: "Anchura",
    Weight: "Peso",
    Intensity: "Intensidad",
    Text: "Texto",
    LabelInfo: "Etiqueta",
    LabelSizeInfo: "Tamaño de etiqueta",
    GroupInfo: "Grupo",
    BorderInfo: "Borde",
    OrderInfo: "Orden",
    SizeInfo: "Tamaño",
    ColorInfo: "Color",
    ShapeInfo: "Forma",
    LegendInfo: "Leyenda",
    WidthInfo: "Anchura",
    WeightInfo: "Peso",
    IntensityInfo: "Intensidad",
    TextInfo: "Texto",
    Layout: "Disposición",
    LayoutInfo: "Disposición",
    Show: "Mostrar",
    Hide: "Ocultar",
    circle: "Círculo",
    cross: "Cruz",
    diamond: "Diamante",
    square: "Cuadrado",
    "triangle-down": "Triangulo-abajo",
    "triangle-up": "Triangulo-arriba",
    trianglesquare: "Triángulo",
    selectacolorscale: "Selecciona una escala de color para ",
    selectacolor: "Selecciona un color para ",
    selectashape: "Selecciona una forma para ",
    selectattribute: "Selecciona un atributo para mostrar como ",
    outof: "de",
    scenarios: "Número de escenarios",
    resetzoom: "Reiniciar zoom",
    zoomin: "Ampliar zoom",
    zoomout: "Disminuir zoom",
    removefilter: "Quitar filtro",
    alertrecordheatmap: "El heatmap no puede ser grabado.",
    speed: "Velocidad",
    searchintable: "Busca en la tabla",
    goback: "Volver",
    home: "Home",
    newtab: "Abrir en nueva pestaña",
    tools: "Herramientas",
    poweredby: "Hecho con",
    isolateInfo: "Permite ver únicamente el nodo (o nodos) seleccionado",
    filterInfo: "Permite ver el nodo (o nodos) seleccionado y su red (nodos con los que está relacionado)",
    selectcustomcolor: "Selecciona un color personalizado",
    filterselection: "Filtrar selección",
    Elements: "Elementos",
    more: "más",
    less: "menos",
    Scale: "Escala",
    Table: "Tabla",
    goto: "ir a",
    showonlyselecteditems: "Mostrar solo items seleccionados",
    Relations: "Relaciones",
    Variable: "Variable",
    Value: "Valor",
    highlightneighbors: "Resaltar vecinos",
    clearfilters: "Limpiar filtros",
    close: "Cerrar",
    filtermenu: "Menu de filtros"
  };

==> rD3plot_1.1.45.zip: rD3plot/www/es.js <==
// texts to translate
var texts = {
    graph : "Gráfico",
    nodes : "Nodos",
    general: "General",
    links: "Enlaces",
    apply: "Aplicar",
    filter: "Filtrar",
    isolate: "Aislar",
    select: "Seleccionar",
    clear: "Limpiar",
    add: "Añadir",
    nodesattributes: "Atributos de nodos",
    linksattributes: "Atributos de enlaces",
    elementsattributes: "Atributos de elementos",
    nonodesselected: "Seleciona un nodo en el gráfico para ver sus atributos.",
    nolinksselected: "Seleciona un enlace en el gráfico para ver sus atributos.",
    noitemsselected: "Selecciona nodos o enlaces.",
    noelementsselected: "Selecciona elementos en el gráfico para ver sus atributos.",
    repulsion: "Repulsión",
    distance: "Distancia",
    loading: "Cargando...",
    pdfexport: "Exportación PDF",
    svgexport: "Exportación SVG",
    pngexport: "Exportación PNG",
    showHelp: "Mostrar ayuda",
    showhidelegend: "Leyenda",
    showhideaxes: "Ejes",
    showhidesidebar: "Mostrar/ocultar control lateral",
    showhidebuttons: "Mostrar/ocultar botones",
    showhidetables: "Mostrar/ocultar tablas",
    stopresume: "Dinámico",
    heatmap: "Heatmap",
    resetfilter: "Quitar filtros",
    selectall: "Seleccionar todos",
    selectallnone: "Seleccionar todos / ninguno",
    selectneighbors: "Añadir vecinos",
    expand: "Expandir",
    collapse: "Contraer",
    Reverse: "Invertir",
    tableselection: "Marcados en la tabla",
    reset: "Reiniciar",
    directional: "Flechas",
    degree: "grado",
    none: "Nada",
    default: "Por defecto",
    downloadtable: "Descargar tabla",
    total: "Total",
    concoincidences: "Coincidencias condicionales",
    coincidences: "Coincidencias",
    ofsomeone: "de",
    withsomeone: "con",
    incidences: "Incidencias",
    expected: "Esperadas",
    expectedconfidence: "+/- Confianza esperada",
    confidenceinterval: "+/- Intervalo de confianza",
    subjectselect: "Evento",
    Label: "Etiqueta",
    LabelSize: "Tam.Eti.",
    Group: "Grupo",
    Border: "Borde",
    Order: "Orden",
    Size: "Tamaño",
    Color: "Color",
    Shape: "Forma",
    Legend: "Leyenda",
    Image: "Imagen",
    Width: "Anchura",
    Weight: "Peso",
    Intensity: "Intensidad",
    Text: "Texto",
    LabelInfo: "Etiqueta",
    LabelSizeInfo: "Tamaño de etiqueta",
    GroupInfo: "Grupo",
    BorderInfo: "Borde",
    OrderInfo: "Orden",
    SizeInfo: "Tamaño",
    ColorInfo: "Color",
    ShapeInfo: "Forma",
    LegendInfo: "Leyenda",
    WidthInfo: "Anchura",
    WeightInfo: "Peso",
    IntensityInfo: "Intensidad",
    TextInfo: "Texto",
    Layout: "Disposición",
    LayoutInfo: "Disposición",
    Show: "Mostrar",
    Hide: "Ocultar",
    circle: "Círculo",
    cross: "Cruz",
    diamond: "Diamante",
    square: "Cuadrado",
    "triangle-down": "Triangulo-abajo",
    "triangle-up": "Triangulo-arriba",
    trianglesquare: "Triángulo",
    selectacolorscale: "Selecciona una escala de color para ",
    selectacolor: "Selecciona un color para ",
    selectashape: "Selecciona una forma para ",
    selectattribute: "Selecciona un atributo para mostrar como ",
    outof: "de",
    scenarios: "Número de escenarios",
    resetzoom: "Reiniciar zoom",
    zoomin: "Ampliar zoom",
    zoomout: "Disminuir zoom",
    removefilter: "Quitar filtro",
    alertrecordheatmap: "El heatmap no puede ser grabado.",
    speed: "Velocidad",
    searchintable: "Busca en la tabla",
    goback: "Volver",
    home: "Home",
    newtab: "Abrir en nueva pestaña",
    tools: "Herramientas",
    poweredby: "Hecho con",
    isolateInfo: "Permite ver únicamente el nodo (o nodos) seleccionado",
    filterInfo: "Permite ver el nodo (o nodos) seleccionado y su red (nodos con los que está relacionado)",
    selectcustomcolor: "Selecciona un color personalizado",
    filterselection: "Filtrar selección",
    Elements: "Elementos",
    more: "más",
    less: "menos",
    Scale: "Escala",
    Table: "Tabla",
    goto: "ir a",
    showonlyselecteditems: "Mostrar solo items seleccionados",
    Relations: "Relaciones",
    Variable: "Variable",
    Value: "Valor",
    highlightneighbors: "Resaltar vecinos",
    clearfilters: "Limpiar filtros",
    close: "Cerrar",
    filtermenu: "Menu de filtros",
    noresults: "Sin resultados",
    jointfilter: "Filtro conjunto"
  };
